function [yarray, t] = readNfastframes(filename, Nframes)
% function [yarray, t] = readNfastframes(filename, Nframes)
% 
% loads certain number (<Nframes>) of frames from *.wfm file (<filename>)
% saved by Tektronix TDS5000/B, TDS6000/B/C, or TDS/CSA7000/B, MSO70000/C,
% DSA70000/B/C DPO70000/B/C DPO7000/ MSO/DPO5000
% instrument families into the variables <yarray> (y data) and <t> (time data).
% <yarray> is two dimensional array with size <Nframes> times number of data points.
% <t> is one dimensional array containing certain number of data points.
% 
% The function uses <wfm2readframe.m> file to read a single frame from the file.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reading the first frame from the file to define the size of the frames.
[ytest, t, info, ind_over, ind_under] = wfm2readframe(filename,1,2000,1,1);
[s1 s2] = size(ytest);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reading requested frames into <yarray> variable.
yarray = zeros(Nframes,s1);

for nf=1:Nframes
        
   [ysingle, t, info, ind_over, ind_under] = wfm2readframe(filename,nf,2000,1,1); 
   yarray(nf,:)=ysingle;
   
end

end
